package de.thdeg.greiner.superpangworld.game.managers;

import de.thdeg.greiner.superpangworld.gameview.GameView;
import de.thdeg.greiner.superpangworld.graphics.base.Bubble;
import de.thdeg.greiner.superpangworld.graphics.base.GameObject;
import de.thdeg.greiner.superpangworld.graphics.immovable.*;
import de.thdeg.greiner.superpangworld.graphics.moveable.*;

import java.awt.*;
import java.util.LinkedList;

/**
 * The manager handling the display and passive movement of the game objects.
 */
class GameObjectManager {

    /** The GameView to display the objects */
    private GameView gameView;

    /** The game objects */
    private LinkedList<Bubble> bubbles;
    private LinkedList<Harpoon> harpoons;
    private LevelProgressBar levelProgressBar;
    private LevelLabel levelLabel;
    private ScoreLabel scoreLabel;
    private LivesIcon livesIcon;
    private Background background;
    private Player player;

    private LinkedList<GameObject> gameObjects;

    /**
     * Create a manager handling the display and passive movement of the game objects.
     * @param gameView the GameView
     */
    public GameObjectManager(GameView gameView){
        this.gameView = gameView;
        gameView.setColorForBlockImage('k', Color.LIGHT_GRAY);

        bubbles = new LinkedList<>();
        harpoons = new LinkedList<>();
        gameObjects = new LinkedList<>();

        bubbles.add(new RoundBubble(gameView));
        bubbles.add(new HexagonalBubble(gameView));
        bubbles.add(new SpecialBubble(gameView));

        harpoons.add(new Harpoon(gameView));

        this.levelProgressBar = new LevelProgressBar(gameView);
        this.levelLabel = new LevelLabel(gameView);
        this.scoreLabel = new ScoreLabel(gameView);

        this.livesIcon = new LivesIcon(gameView);

        this.background = new Background(gameView);

        this.player = new Player(gameView);

    }

    /**
     * Add the objects to the canvas and handle update their positions.
     */
    public void updateGameObjects(){
        gameObjects.clear();
        gameObjects.add(background);
        gameObjects.addAll(bubbles);
        gameObjects.addAll(harpoons);
        gameObjects.add(levelProgressBar);
        gameObjects.add(levelLabel);
        gameObjects.add(scoreLabel);
        gameObjects.add(livesIcon);
        gameObjects.add(player);

        gameObjects.forEach(gameObject ->{
            gameObject.updatePosition();
            gameObject.updateStatus();
            gameObject.addToCanvas();
        });
    }

    /**
     * Get the player object.
     * @return the player
     */
    public Player getPlayer(){
        return player;
    }

    /**
     * Get the bubbles.
     * @return the bubbles
     */
    public LinkedList<Bubble> getBubbles() {
        return bubbles;
    }

    /**
     * Get the harpoons.
     * @return the harpoons
     */
    public LinkedList<Harpoon> getHarpoons() {
        return harpoons;
    }
}
