package de.thdeg.greiner.superpangworld.game.managers;

import de.thdeg.greiner.superpangworld.gameview.GameView;
import de.thdeg.greiner.superpangworld.graphics.moveable.Player;

import java.awt.event.KeyEvent;
import java.util.Arrays;

/**
 * The manager which handles the user input and controls the player object.
 */
class InputManager {

    /** The gameView, which displays the player object */
    private GameView gameView;
    /** The player object */
    private Player player;
    /** Flag, if diagonal movement is allowed */
    private static final boolean DIAGONAL_MOVEMENT_ALLOWED = false;

    /**
     * Create a manager handling the user input
     * @param gameView the GameView
     * @param player the player object
     */
    public InputManager(GameView gameView, Player player){
        this.gameView = gameView;
        this.player = player;
    }

    /**
     * Read the user inputs and perform actions accordingly
     */
    public void updateUserInputs() {
        Integer[] gedruekteTasten = gameView.getKeyCodesOfCurrentlyPressedKeys();
        if(Arrays.stream(gedruekteTasten).anyMatch(k -> k == KeyEvent.VK_SPACE)){
            player.shoot();
        }
        for (int keyCode : gedruekteTasten) {
            switch(keyCode) {
                case KeyEvent.VK_LEFT:
                    player.left();
                    break;
                case KeyEvent.VK_RIGHT:
                    player.right();
                    break;
                default:
                    continue;
            }
            if(!DIAGONAL_MOVEMENT_ALLOWED){
                return;
            }
        }
    }



}
